from setuptools import setup

setup(name='geosearch_py',
      version='0.1',
      description='A Python implementation of Gmaps geocode API, capable or returning viewport and geometric bounds',
      url='https://github.com/csunsong/geosearch_py',
      author='Chris Sunsong',
      author_email='csunsong@gmail.com',
      license='MIT',
      packages=['geosearch_py'],
      zip_safe=False)
